@@ -7,10 +7,10 @@ from ..util import ToDenseWarning
 __all__ = []
 
 
-@B.dispatch(AbstractMatrix, AbstractMatrix)
-def divide(a, b):
+@B.dispatch
+def divide(a: AbstractMatrix, b: AbstractMatrix):
     if structured(a, b):
         warn_upmodule(
             f"Dividing {a} by {b}: converting to dense.", category=ToDenseWarning
         )
-    return Dense(B.divide(B.dense(a), B.dense(b)))
+    return Dense(B.divide(B.dense(a), B.dense(b)))
\ No newline at end of file
