@@ -6,7 +6,7 @@ from ..shape import assert_square
 __all__ = []
 
 
-@B.dispatch(AbstractMatrix)
-def eye(a):
+@B.dispatch
+def eye(a: AbstractMatrix):
     assert_square(a, "Can only construct identity matrices from square matrices.")
-    return B.fill_diag(B.one(a), B.shape(a)[0])
+    return B.fill_diag(B.one(a), B.shape(a)[0])
\ No newline at end of file
