@@ -1,5 +1,6 @@
 import lab as B
 
+from ..lowrank import LowRank
 from ..woodbury import Woodbury
 
 __all__ = []
@@ -37,4 +38,11 @@ def iqf(a, b):
 
 @B.dispatch
 def iqf(a: Woodbury, b, c):
-    return B.mm(b, B.pd_inv(a), c, tr_a=True)
\ No newline at end of file
+    return B.mm(b, B.pd_inv(a), c, tr_a=True)
+
+
+# @B.dispatch
+# def iqf(a: Woodbury, b: LowRank, c: LowRank):
+#     middle_left = B.mm(b.right, b.middle, tr_b=True)
+#     middle_right = B.mm(c.right, c.middle, tr_b=True)
+#     return LowRank(b.right, c.right, B.iqf(a, middle_left, middle_right))
