@@ -71,7 +71,7 @@ def multiply(a: Diagonal, b: AbstractMatrix):
         b_diag = B.squeeze(B.dense(b))
     else:
         b_diag = B.diag(b)
-    return Diagonal(a.diag * b_diag)
+    return Diagonal(B.multiply(a.diag, b_diag))
 
 
 _reverse_call(Diagonal, AbstractMatrix)
@@ -83,7 +83,7 @@ _reverse_call(Diagonal, AbstractMatrix)
 @B.dispatch
 def multiply(a: Constant, b: Constant):
     assert_compatible(a, b)
-    return Constant(a.const * b.const, *broadcast(a, b).as_tuple())
+    return Constant(B.multiply(a.const, b.const), *broadcast(a, b).as_tuple())
 
 
 @B.dispatch
@@ -93,13 +93,15 @@ def multiply(a: Constant, b: AbstractMatrix):
         warn_upmodule(
             f"Multiplying {a} and {b}: converting to dense.", category=ToDenseWarning
         )
-    return Dense(B.broadcast_to(a.const * B.dense(b), *broadcast(a, b).as_tuple()))
+    return Dense(
+        B.broadcast_to(B.multiply(a.const, B.dense(b)), *broadcast(a, b).as_tuple())
+    )
 
 
 @B.dispatch
 def multiply(a: Constant, b: Diagonal):
     assert_compatible(a, b)
-    return Diagonal(a.const * b.diag)
+    return Diagonal(B.multiply(a.const, b.diag))
 
 
 _reverse_call(Constant, AbstractMatrix)
@@ -117,7 +119,7 @@ def multiply(a: LowerTriangular, b: LowerTriangular):
 @B.dispatch
 def multiply(a: LowerTriangular, b: AbstractMatrix):
     # TODO: Optimise away `B.dense` call.
-    return LowerTriangular(a.mat * B.dense(b))
+    return LowerTriangular(B.multiply(a.mat, B.dense(b)))
 
 
 @B.dispatch
@@ -237,9 +239,10 @@ redirect(B.multiply, (Woodbury, UpperTriangular), (Woodbury, AbstractMatrix))
 def multiply(a: Kronecker, b: Kronecker):
     left_compatible = B.shape(a.left) == B.shape(b.left)
     right_compatible = B.shape(a.right) == B.shape(b.right)
-    assert (
-        left_compatible and right_compatible
-    ), f"Kronecker products {a} and {b} must be compatible, but they are not."
+    if not (left_compatible and right_compatible):
+        raise AssertionError(
+            f"Kronecker products {a} and {b} must be compatible, but they are not."
+        )
     assert_compatible(a.left, b.left)
     assert_compatible(a.right, b.right)
     return Kronecker(B.multiply(a.left, b.left), B.multiply(a.right, b.right))
@@ -248,7 +251,7 @@ def multiply(a: Kronecker, b: Kronecker):
 @B.dispatch
 def multiply(a: Constant, b: Kronecker):
     assert_compatible(a, b)
-    return Kronecker(a.const * b.left, b.right)
+    return Kronecker(B.multiply(a.const, b.left), b.right)
 
 
 @B.dispatch
