@@ -1,6 +1,6 @@
 import lab as B
 
-from plum import convert
+from plum import convert, Union
 from ..diagonal import Diagonal
 from ..kronecker import Kronecker
 from ..matrix import AbstractMatrix
@@ -10,8 +10,8 @@ from ..woodbury import Woodbury
 __all__ = []
 
 
-@B.dispatch({B.Numeric, AbstractMatrix})
-def pd_inv(a):
+@B.dispatch
+def pd_inv(a: Union[B.Numeric, AbstractMatrix]):
     """Invert a positive-definite matrix.
 
     Args:
@@ -27,13 +27,13 @@ def pd_inv(a):
     return B.cholesky_solve(B.cholesky(a), B.dense(B.eye(a)))
 
 
-@B.dispatch(Diagonal)
-def pd_inv(a):
+@B.dispatch
+def pd_inv(a: Diagonal):
     return B.inv(a)
 
 
-@B.dispatch(Woodbury)
-def pd_inv(a):
+@B.dispatch
+def pd_inv(a: Woodbury):
     diag_inv = B.inv(a.diag)
     # See comment in `inv`.
     return B.subtract(
@@ -46,8 +46,8 @@ def pd_inv(a):
     )
 
 
-@B.dispatch(Kronecker)
-def pd_inv(a):
+@B.dispatch
+def pd_inv(a: Kronecker):
     return Kronecker(B.pd_inv(a.left), B.pd_inv(a.right))
 
 
