@@ -5,8 +5,8 @@ from ..woodbury import Woodbury
 __all__ = []
 
 
-@B.dispatch(Woodbury)
-def pd_schur(a):
+@B.dispatch
+def pd_schur(a: Woodbury):
     """Compute the Schur complement associated to a positive-definite matrix. A Schur
     complement will need to make sense for the type of `a`.
 
@@ -22,4 +22,4 @@ def pd_schur(a):
     return a.schur
 
 
-B.pd_schur = pd_schur
+B.pd_schur = pd_schur
\ No newline at end of file
