@@ -5,6 +5,6 @@ from ..matrix import AbstractMatrix
 __all__ = []
 
 
-@B.dispatch(AbstractMatrix)
-def rank(a):
-    return 2
+@B.dispatch
+def rank(a: AbstractMatrix):
+    return 2
\ No newline at end of file
