@@ -5,6 +5,6 @@ from ..matrix import AbstractMatrix
 __all__ = []
 
 
-@B.dispatch(AbstractMatrix)
-def uprank(a):
-    return a
+@B.dispatch
+def uprank(a: AbstractMatrix):
+    return a
\ No newline at end of file
