@@ -47,6 +47,11 @@ from ..util import (
 _dispatch = Dispatcher()
 
 
+def test_add_zero_dense(zero1, dense_bc):
+    check_bin_op(B.add, zero1, dense_bc, asserted_type=Dense)
+    check_bin_op(B.add, dense_bc, zero1, asserted_type=Dense)
+
+
 def test_add_zero_diag(zero1, diag2):
     check_bin_op(B.add, zero1, diag2, asserted_type=Diagonal)
     check_bin_op(B.add, diag2, zero1, asserted_type=Diagonal)
@@ -68,12 +73,9 @@ def test_add_const(const_or_scalar1, const2):
     check_bin_op(B.add, const_or_scalar1, const2, asserted_type=Constant)
 
 
-def test_add_const_dense(const_or_scalar1, dense2):
-    # We don't test for broadcasting behaviour here because the resulting
-    # shapes will be different: the constant matrix will not affect the
-    # resulting shape.
-    check_bin_op(B.add, const_or_scalar1, dense2, asserted_type=Dense)
-    check_bin_op(B.add, dense2, const_or_scalar1, asserted_type=Dense)
+def test_add_const_dense(const_or_scalar1, dense_bc):
+    check_bin_op(B.add, const_or_scalar1, dense_bc, asserted_type=Dense)
+    check_bin_op(B.add, dense_bc, const_or_scalar1, asserted_type=Dense)
 
 
 def test_add_const_diag(const_or_scalar1, diag2):
