@@ -1,7 +1,7 @@
 import lab as B
 
 # noinspection PyUnresolvedReferences
-from ..util import allclose, check_un_op, AssertDenseWarning, diag_pd, lr_pd, wb_pd
+from ..util import approx, check_un_op, AssertDenseWarning, diag_pd, lr_pd, wb_pd
 
 
 # Correctness is tested in `logdet` et cetera.
