@@ -5,7 +5,7 @@ from matrix import Dense, Diagonal, Constant, LowRank, Woodbury, Kronecker, Zero
 
 # noinspection PyUnresolvedReferences
 from ..util import (
-    allclose,
+    approx,
     check_un_op,
     zero_r,
     dense_r,
